==> watson_machine_learning_client-1.0.317.tar.gz: watson_machine_learning_client-1.0.317/watson_machine_learning_client/libs/repository_v3/mlrepositoryartifact/tensorflow_artifact_loader.py <==
################################################################################
#
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2017
# US Government Users Restricted Rights - Use, duplication disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp.
#
################################################################################


from repository_v3.util.compression_util import CompressionUtil
from repository_v3.util.unique_id_gen import uid_generate
import os, shutil


class TensorflowArtifactLoader(object):
    def load(self,session,tags):
        return self.extract_content(lambda content_dir: self.load_content(content_dir,session,tags))

    def extract_content(self, callback):
        directory_name = 'artifact'
        try:
            shutil.rmtree(directory_name)
        except:
            pass

        try:
            id_length = 20
            dir_id = uid_generate(id_length)
            model_dir_name = directory_name + dir_id
            tar_file_name = '{}/artifact_content.tar'.format(model_dir_name)
            gz_file_name = '{}/artifact_content.tar.gz'.format(model_dir_name)

            os.makedirs(model_dir_name)
            input_stream = self.reader().read()
            file_content = input_stream.read()
            gz_f = open(gz_file_name, 'wb+')
            gz_f.write(file_content)
            gz_f.close()
            self.reader().close()
            CompressionUtil.decompress_file_gzip(gz_file_name, tar_file_name)
            CompressionUtil.extract_tar(tar_file_name, model_dir_name)
            tensorflowRuntimeArtifact = callback(model_dir_name)
            shutil.rmtree(model_dir_name)
            return tensorflowRuntimeArtifact
        except Exception as ex:
            shutil.rmtree(model_dir_name)
            raise ex

==> watson_machine_learning_client-1.0.355.tar.gz: watson_machine_learning_client-1.0.355/watson_machine_learning_client/libs/repository_v3/mlrepositoryartifact/tensorflow_artifact_loader.py <==
################################################################################
#
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2017
# US Government Users Restricted Rights - Use, duplication disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp.
#
################################################################################


from watson_machine_learning_client.libs.repository_v3.util.compression_util import CompressionUtil
from watson_machine_learning_client.libs.repository_v3.util.unique_id_gen import uid_generate
import os, shutil


class TensorflowArtifactLoader(object):
    def load(self,session,tags):
        return self.extract_content(lambda content_dir: self.load_content(content_dir,session,tags))

    def extract_content(self, callback):
        directory_name = 'artifact'
        try:
            shutil.rmtree(directory_name)
        except:
            pass

        try:
            id_length = 20
            dir_id = uid_generate(id_length)
            model_dir_name = directory_name + dir_id
            tar_file_name = '{}/artifact_content.tar'.format(model_dir_name)
            gz_file_name = '{}/artifact_content.tar.gz'.format(model_dir_name)

            os.makedirs(model_dir_name)
            input_stream = self.reader().read()
            file_content = input_stream.read()
            gz_f = open(gz_file_name, 'wb+')
            gz_f.write(file_content)
            gz_f.close()
            self.reader().close()
            CompressionUtil.decompress_file_gzip(gz_file_name, tar_file_name)
            CompressionUtil.extract_tar(tar_file_name, model_dir_name)
            tensorflowRuntimeArtifact = callback(model_dir_name)
            shutil.rmtree(model_dir_name)
            return tensorflowRuntimeArtifact
        except Exception as ex:
            shutil.rmtree(model_dir_name)
            raise ex
